# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.board_ticket_statuses_api import BoardTicketStatusesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBoardTicketStatusesApi(unittest.TestCase):
    """BoardTicketStatusesApi unit test stubs"""

    def setUp(self):
        self.api = BoardTicketStatusesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_status(self):
        """Test case for create_status

        Creates a status  # noqa: E501
        """
        pass

    def test_delete_status(self):
        """Test case for delete_status

        Deletes the Status with the specified id.  # noqa: E501
        """
        pass

    def test_get_default_statuses(self):
        """Test case for get_default_statuses

        Gets a list of the default statuses in arbitrary,  static order.    The ids specified on these StatusChildren are to allow easy differentiation on  the frontend. They do not represent anything stored in the db.  # noqa: E501
        """
        pass

    def test_get_status(self):
        """Test case for get_status

        Gets a Status  # noqa: E501
        """
        pass

    def test_update_status(self):
        """Test case for update_status

        Updates the status with the specified id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
