# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.tags_api import TagsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Creates a tag  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Gets a tag  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Gets tags  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Updates a tag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
