# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.groups_api import GroupsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_analytics_model_to_group(self):
        """Test case for add_analytics_model_to_group

        Add Analytics Models to a Group  # noqa: E501
        """
        pass

    def test_delete_analytics_model_from_group(self):
        """Test case for delete_analytics_model_from_group

        Deletes an Analytics Model from group  # noqa: E501
        """
        pass

    def test_get_bearings_for_group(self):
        """Test case for get_bearings_for_group

        Gets all bearings for a group  # noqa: E501
        """
        pass

    def test_get_group_alerts(self):
        """Test case for get_group_alerts

        Please use ​GET /api​/v3.0​/Alerts  Gets the alerts for the given group  # noqa: E501
        """
        pass

    def test_get_group_analytics_model(self):
        """Test case for get_group_analytics_model

        Gets a Group Analytics Model  # noqa: E501
        """
        pass

    def test_get_group_analytics_models(self):
        """Test case for get_group_analytics_models

        Gets Analytics Models assigned to a group  # noqa: E501
        """
        pass

    def test_get_group_analytics_models_for_group(self):
        """Test case for get_group_analytics_models_for_group

        Gets Analytics Models assigned to a specific group  # noqa: E501
        """
        pass

    def test_update_analytics_model_on_group(self):
        """Test case for update_analytics_model_on_group

        Updates Analytics Models for a Group  # noqa: E501
        """
        pass

    def test_update_bearings_for_group(self):
        """Test case for update_bearings_for_group

        Updates bearings for a group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
