# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.thermal_cameras_api import ThermalCamerasApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestThermalCamerasApi(unittest.TestCase):
    """ThermalCamerasApi unit test stubs"""

    def setUp(self):
        self.api = ThermalCamerasApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_thermal_camera(self):
        """Test case for create_thermal_camera

        Create ThermalCamera object with associated ThermalCameraSettings  # noqa: E501
        """
        pass

    def test_create_thermal_camera_region(self):
        """Test case for create_thermal_camera_region

        Creates a Thermal Camera Region  # noqa: E501
        """
        pass

    def test_delete_thermal_camera(self):
        """Test case for delete_thermal_camera

        Deletes a ThermalCamera object and it's associated objects:  Regions, Images, Settings  # noqa: E501
        """
        pass

    def test_delete_thermal_camera_region(self):
        """Test case for delete_thermal_camera_region

        Deletes a Thermal Camera Region  # noqa: E501
        """
        pass

    def test_get_image(self):
        """Test case for get_image

        Gets a single thermal camera image  # noqa: E501
        """
        pass

    def test_get_latest_image(self):
        """Test case for get_latest_image

        Gets the latest ThermalCameraImage for a ThermalCamera  # noqa: E501
        """
        pass

    def test_get_thermal_camera(self):
        """Test case for get_thermal_camera

        Get a single ThermalCamera object  # noqa: E501
        """
        pass

    def test_get_thermal_camera_region(self):
        """Test case for get_thermal_camera_region

        Gets a single Thermal Camera Region  # noqa: E501
        """
        pass

    def test_get_thermal_camera_regions(self):
        """Test case for get_thermal_camera_regions

        Gets Thermal Camera Regions  # noqa: E501
        """
        pass

    def test_get_thermal_cameras(self):
        """Test case for get_thermal_cameras

        Get multiple ThermalCamera objects  # noqa: E501
        """
        pass

    def test_update_thermal_camera(self):
        """Test case for update_thermal_camera

        Updates a single Thermal Camera/ settings  # noqa: E501
        """
        pass

    def test_update_thermal_camera_region(self):
        """Test case for update_thermal_camera_region

        Updates a single Thermal Camera Region  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
