# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.indicator_groups_api import IndicatorGroupsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestIndicatorGroupsApi(unittest.TestCase):
    """IndicatorGroupsApi unit test stubs"""

    def setUp(self):
        self.api = IndicatorGroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_indicator_group(self):
        """Test case for create_indicator_group

        Creates a indicatorGroup  # noqa: E501
        """
        pass

    def test_delete_indicator_group(self):
        """Test case for delete_indicator_group

        Deletes a indicatorGroup  # noqa: E501
        """
        pass

    def test_get_indicator_group(self):
        """Test case for get_indicator_group

        Gets a indicatorGroup  # noqa: E501
        """
        pass

    def test_get_indicator_groups(self):
        """Test case for get_indicator_groups

        Gets indicatorGroups  # noqa: E501
        """
        pass

    def test_move_indicator_group(self):
        """Test case for move_indicator_group

        Moves a indicatorGroup  # noqa: E501
        """
        pass

    def test_update_indicator_group(self):
        """Test case for update_indicator_group

        Updates a indicatorGroup  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
