# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MetricTypeCodes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    TEMPERATURE = "Temperature"
    PRESSURE = "Pressure"
    FLOW = "Flow"
    HUMIDITY = "Humidity"
    POWER = "Power"
    DIFFERENTIALPRESSURE = "DifferentialPressure"
    VOLTAGE = "Voltage"
    GENERALIZEDATOD = "GeneralizedAtoD"
    VIBRATIONBANDRMS = "VibrationBandRms"
    VIBRATIONBANDMAX = "VibrationBandMax"
    VIBRATIONOVERALLPEAK = "VibrationOverallPeak"
    VIBRATIONOVERALLRMS = "VibrationOverallRms"
    VIBRATIONOVERALLSKEWNESS = "VibrationOverallSkewness"
    VIBRATIONOVERALLKURTOSIS = "VibrationOverallKurtosis"
    VIBRATIONOVERALLCRESTFACTOR = "VibrationOverallCrestFactor"
    DAMAGEACCUMULATION = "DamageAccumulation"
    VIBRATIONBANDRMSACCEL = "VibrationBandRmsAccel"
    VIBRATIONBANDMAXACCEL = "VibrationBandMaxAccel"
    VIBRATIONOVERALLPEAKACCEL = "VibrationOverallPeakAccel"
    VIBRATIONOVERALLRMSACCEL = "VibrationOverallRmsAccel"
    VIBRATIONOVERALLSKEWNESSACCEL = "VibrationOverallSkewnessAccel"
    VIBRATIONOVERALLKURTOSISACCEL = "VibrationOverallKurtosisAccel"
    VIBRATIONOVERALLCRESTFACTORACCEL = "VibrationOverallCrestFactorAccel"
    DAMAGEACCUMULATIONACCEL = "DamageAccumulationAccel"
    GROUP = "Group"
    VIBRATIONOVERALL = "VibrationOverall"
    VIBRATIONOVERALLACCEL = "VibrationOverallAccel"
    GENERALTIMESERIES = "GeneralTimeSeries"
    MATH = "Math"
    ONSTATISTICS = "OnStatistics"
    OFFSTATISTICS = "OffStatistics"
    ALARMSTATISTICS = "AlarmStatistics"
    WARNINGSTATISTICS = "WarningStatistics"
    POSITIVEPEAKPRESSURE = "PositivePeakPressure"
    NEGATIVEPEAKPRESSURE = "NegativePeakPressure"
    RMSPRESSURE = "RmsPressure"
    BANDPRESSURE = "BandPressure"
    ONPERCENTSTATISTICS = "OnPercentStatistics"
    OFFPERCENTSTATISTICS = "OffPercentStatistics"
    ALARMPERCENTSTATISTICS = "AlarmPercentStatistics"
    WARNINGPERCENTSTATISTICS = "WarningPercentStatistics"
    SIGNALSTRENGTH = "SignalStrength"
    RUNNINGSPEED = "RunningSpeed"
    DAMAGEACCUMULATIONPRESSURE = "DamageAccumulationPressure"
    OILHUMIDITY = "OilHumidity"
    OILTEMPERATURE = "OilTemperature"
    DAMAGEACCUMULATIONACCELRAW = "DamageAccumulationAccelRaw"
    THERMALREGIONOFINTEREST = "ThermalRegionOfInterest"
    SMARTMETRIC = "SmartMetric"
    FEATURE = "Feature"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """MetricTypeCodes - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MetricTypeCodes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricTypeCodes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
