# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PropertyRequestChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'property_name': 'str',
        'property_value_type': 'PropertyValueType',
        'property_required': 'bool'
    }

    attribute_map = {
        'property_name': 'PropertyName',
        'property_value_type': 'PropertyValueType',
        'property_required': 'PropertyRequired'
    }

    def __init__(self, property_name=None, property_value_type=None, property_required=None):  # noqa: E501
        """PropertyRequestChild - a model defined in Swagger"""  # noqa: E501
        self._property_name = None
        self._property_value_type = None
        self._property_required = None
        self.discriminator = None
        self.property_name = property_name
        self.property_value_type = property_value_type
        self.property_required = property_required

    @property
    def property_name(self):
        """Gets the property_name of this PropertyRequestChild.  # noqa: E501


        :return: The property_name of this PropertyRequestChild.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this PropertyRequestChild.


        :param property_name: The property_name of this PropertyRequestChild.  # noqa: E501
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")  # noqa: E501

        self._property_name = property_name

    @property
    def property_value_type(self):
        """Gets the property_value_type of this PropertyRequestChild.  # noqa: E501


        :return: The property_value_type of this PropertyRequestChild.  # noqa: E501
        :rtype: PropertyValueType
        """
        return self._property_value_type

    @property_value_type.setter
    def property_value_type(self, property_value_type):
        """Sets the property_value_type of this PropertyRequestChild.


        :param property_value_type: The property_value_type of this PropertyRequestChild.  # noqa: E501
        :type: PropertyValueType
        """
        if property_value_type is None:
            raise ValueError("Invalid value for `property_value_type`, must not be `None`")  # noqa: E501

        self._property_value_type = property_value_type

    @property
    def property_required(self):
        """Gets the property_required of this PropertyRequestChild.  # noqa: E501


        :return: The property_required of this PropertyRequestChild.  # noqa: E501
        :rtype: bool
        """
        return self._property_required

    @property_required.setter
    def property_required(self, property_required):
        """Sets the property_required of this PropertyRequestChild.


        :param property_required: The property_required of this PropertyRequestChild.  # noqa: E501
        :type: bool
        """
        if property_required is None:
            raise ValueError("Invalid value for `property_required`, must not be `None`")  # noqa: E501

        self._property_required = property_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PropertyRequestChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PropertyRequestChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
