# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.models.hub_power_type import HubPowerType  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestHubPowerType(unittest.TestCase):
    """HubPowerType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHubPowerType(self):
        """Test HubPowerType"""
        # FIXME: construct object with mandatory attributes with example values
        # model = smart_diagnostics_client.models.hub_power_type.HubPowerType()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
