# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.sub_systems_api import SubSystemsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestSubSystemsApi(unittest.TestCase):
    """SubSystemsApi unit test stubs"""

    def setUp(self):
        self.api = SubSystemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_sub_system(self):
        """Test case for create_sub_system

        Creates a subSystem  # noqa: E501
        """
        pass

    def test_delete_sub_system(self):
        """Test case for delete_sub_system

        Deletes a subSystem  # noqa: E501
        """
        pass

    def test_get_sub_system(self):
        """Test case for get_sub_system

        Gets a subSystem  # noqa: E501
        """
        pass

    def test_get_sub_systems(self):
        """Test case for get_sub_systems

        Gets subSystems  # noqa: E501
        """
        pass

    def test_move_sub_system(self):
        """Test case for move_sub_system

        Moves a subSystem  # noqa: E501
        """
        pass

    def test_update_sub_system(self):
        """Test case for update_sub_system

        Updates a subSystem  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
