# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.scheduled_report_subscription_api import ScheduledReportSubscriptionApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestScheduledReportSubscriptionApi(unittest.TestCase):
    """ScheduledReportSubscriptionApi unit test stubs"""

    def setUp(self):
        self.api = ScheduledReportSubscriptionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_scheduled_report_subscription(self):
        """Test case for create_scheduled_report_subscription

        Creates a scheduled report subscription  # noqa: E501
        """
        pass

    def test_delete_scheduled_report_subscription(self):
        """Test case for delete_scheduled_report_subscription

        Deletes a scheduled report subscription  # noqa: E501
        """
        pass

    def test_get_scheduled_report_subscription(self):
        """Test case for get_scheduled_report_subscription

        Gets a single scheduled report subscription  # noqa: E501
        """
        pass

    def test_get_scheduled_report_subscriptions(self):
        """Test case for get_scheduled_report_subscriptions

        Get multiple scheduled report subscriptions  # noqa: E501
        """
        pass

    def test_update_scheduled_report_subscription(self):
        """Test case for update_scheduled_report_subscription

        Updates a scheduled report subscription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
