# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.corporations_api import CorporationsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestCorporationsApi(unittest.TestCase):
    """CorporationsApi unit test stubs"""

    def setUp(self):
        self.api = CorporationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_corporation(self):
        """Test case for create_corporation

        Creates a new corporation  # noqa: E501
        """
        pass

    def test_get_corporation(self):
        """Test case for get_corporation

        Returns a single corporation  # noqa: E501
        """
        pass

    def test_get_corporation_roi(self):
        """Test case for get_corporation_roi

        Gets ROI information for a corporation  # noqa: E501
        """
        pass

    def test_get_corporations(self):
        """Test case for get_corporations

        Returns paginated list corporations  # noqa: E501
        """
        pass

    def test_update_corporation(self):
        """Test case for update_corporation

        Updates a Corporation  # noqa: E501
        """
        pass

    def test_upload_corporation_icon(self):
        """Test case for upload_corporation_icon

        Updates a Corporations Icon  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
