# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.pictures_api import PicturesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestPicturesApi(unittest.TestCase):
    """PicturesApi unit test stubs"""

    def setUp(self):
        self.api = PicturesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_assign_pictures_to_group(self):
        """Test case for assign_pictures_to_group

        Associate an ordered list of pictures to a group  # noqa: E501
        """
        pass

    def test_get_picture(self):
        """Test case for get_picture

        Returns a single picture  # noqa: E501
        """
        pass

    def test_get_pictures(self):
        """Test case for get_pictures

        Returns a paged list of all pictures  # noqa: E501
        """
        pass

    def test_get_pictures_for_group(self):
        """Test case for get_pictures_for_group

        Get a paged list of pictures associated with a group  # noqa: E501
        """
        pass

    def test_get_pictures_for_location(self):
        """Test case for get_pictures_for_location

        Returns a paged list of pictures associated with an account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
