# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.markers_api import MarkersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestMarkersApi(unittest.TestCase):
    """MarkersApi unit test stubs"""

    def setUp(self):
        self.api = MarkersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_marker(self):
        """Test case for create_marker

        Creates a new Marker for an asset  # noqa: E501
        """
        pass

    def test_delete_marker(self):
        """Test case for delete_marker

        Deletes the specified Marker  # noqa: E501
        """
        pass

    def test_get_marker(self):
        """Test case for get_marker

        Gets the specified marker  # noqa: E501
        """
        pass

    def test_update_marker(self):
        """Test case for update_marker

        Updates the specified Marker  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
