# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.analytics_api import AnalyticsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestAnalyticsApi(unittest.TestCase):
    """AnalyticsApi unit test stubs"""

    def setUp(self):
        self.api = AnalyticsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_analytics_assignment(self):
        """Test case for create_analytics_assignment

        Creates a model assignment on a new analytics group under the specified parent group  # noqa: E501
        """
        pass

    def test_create_analytics_models(self):
        """Test case for create_analytics_models

        Creates an Analytics Model  # noqa: E501
        """
        pass

    def test_delete_analytics_assignment(self):
        """Test case for delete_analytics_assignment

        Deletes the model assignment and the analytics group that holds it  # noqa: E501
        """
        pass

    def test_delete_analytics_model(self):
        """Test case for delete_analytics_model

        Deletes an Analytics Model  # noqa: E501
        """
        pass

    def test_get_analytics_assignment(self):
        """Test case for get_analytics_assignment

        Gets the model assignment  # noqa: E501
        """
        pass

    def test_get_analytics_assignments(self):
        """Test case for get_analytics_assignments

        Gets all model assignments  # noqa: E501
        """
        pass

    def test_get_analytics_logs(self):
        """Test case for get_analytics_logs

        Gets logs for the model  # noqa: E501
        """
        pass

    def test_get_analytics_model(self):
        """Test case for get_analytics_model

        Gets an Analytics Model  # noqa: E501
        """
        pass

    def test_get_analytics_model_source(self):
        """Test case for get_analytics_model_source

        Gets the files associated with an analytics model  # noqa: E501
        """
        pass

    def test_get_analytics_model_template(self):
        """Test case for get_analytics_model_template

        Gets the analytics model template file  # noqa: E501
        """
        pass

    def test_get_analytics_models(self):
        """Test case for get_analytics_models

        Gets Analytics Models  # noqa: E501
        """
        pass

    def test_update_analytics_assignment(self):
        """Test case for update_analytics_assignment

        Updates a model assignment  # noqa: E501
        """
        pass

    def test_update_analytics_model_source(self):
        """Test case for update_analytics_model_source

        Updates the files associated with an analytics model  # noqa: E501
        """
        pass

    def test_update_analytics_model_status(self):
        """Test case for update_analytics_model_status

        Updates the status of the model  # noqa: E501
        """
        pass

    def test_update_analytics_models(self):
        """Test case for update_analytics_models

        Updates an Analytics Model  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
