# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventRelationshipCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'relationship_type': 'ActivityEventRelationshipType',
        'from_activity_event_id': 'str',
        'to_activity_event_id': 'str'
    }

    attribute_map = {
        'relationship_type': 'RelationshipType',
        'from_activity_event_id': 'FromActivityEventId',
        'to_activity_event_id': 'ToActivityEventId'
    }

    def __init__(self, relationship_type=None, from_activity_event_id=None, to_activity_event_id=None):  # noqa: E501
        """ActivityEventRelationshipCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._relationship_type = None
        self._from_activity_event_id = None
        self._to_activity_event_id = None
        self.discriminator = None
        self.relationship_type = relationship_type
        self.from_activity_event_id = from_activity_event_id
        self.to_activity_event_id = to_activity_event_id

    @property
    def relationship_type(self):
        """Gets the relationship_type of this ActivityEventRelationshipCreateRequest.  # noqa: E501


        :return: The relationship_type of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :rtype: ActivityEventRelationshipType
        """
        return self._relationship_type

    @relationship_type.setter
    def relationship_type(self, relationship_type):
        """Sets the relationship_type of this ActivityEventRelationshipCreateRequest.


        :param relationship_type: The relationship_type of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :type: ActivityEventRelationshipType
        """
        if relationship_type is None:
            raise ValueError("Invalid value for `relationship_type`, must not be `None`")  # noqa: E501

        self._relationship_type = relationship_type

    @property
    def from_activity_event_id(self):
        """Gets the from_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501


        :return: The from_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._from_activity_event_id

    @from_activity_event_id.setter
    def from_activity_event_id(self, from_activity_event_id):
        """Sets the from_activity_event_id of this ActivityEventRelationshipCreateRequest.


        :param from_activity_event_id: The from_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :type: str
        """
        if from_activity_event_id is None:
            raise ValueError("Invalid value for `from_activity_event_id`, must not be `None`")  # noqa: E501

        self._from_activity_event_id = from_activity_event_id

    @property
    def to_activity_event_id(self):
        """Gets the to_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501


        :return: The to_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._to_activity_event_id

    @to_activity_event_id.setter
    def to_activity_event_id(self, to_activity_event_id):
        """Sets the to_activity_event_id of this ActivityEventRelationshipCreateRequest.


        :param to_activity_event_id: The to_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :type: str
        """
        if to_activity_event_id is None:
            raise ValueError("Invalid value for `to_activity_event_id`, must not be `None`")  # noqa: E501

        self._to_activity_event_id = to_activity_event_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventRelationshipCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventRelationshipCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
