# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.board_tickets_api import BoardTicketsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBoardTicketsApi(unittest.TestCase):
    """BoardTicketsApi unit test stubs"""

    def setUp(self):
        self.api = BoardTicketsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_ticket(self):
        """Test case for create_ticket

        Creates a new ticket  # noqa: E501
        """
        pass

    def test_delete_ticket(self):
        """Test case for delete_ticket

        Deletes a ticket  # noqa: E501
        """
        pass

    def test_get_ticket(self):
        """Test case for get_ticket

        Gets the specified ticket  # noqa: E501
        """
        pass

    def test_get_tickets(self):
        """Test case for get_tickets

        Gets tickets  # noqa: E501
        """
        pass

    def test_update_ticket(self):
        """Test case for update_ticket

        Updates an existing ticket  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
