# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.events_api import EventsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self):
        self.api = EventsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_event(self):
        """Test case for create_event

        This route is obsolete. Please use /api/v3.0/Activities instead.  Creates an event  # noqa: E501
        """
        pass

    def test_export_events(self):
        """Test case for export_events

        Enqueues a report that contains all events for the params  # noqa: E501
        """
        pass

    def test_update_event(self):
        """Test case for update_event

        Updates an Event  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
