# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.tree_items_api import TreeItemsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestTreeItemsApi(unittest.TestCase):
    """TreeItemsApi unit test stubs"""

    def setUp(self):
        self.api = TreeItemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_tree_item(self):
        """Test case for delete_tree_item

        Deletes a treeItem  # noqa: E501
        """
        pass

    def test_get_tree_item(self):
        """Test case for get_tree_item

        Gets a treeItem  # noqa: E501
        """
        pass

    def test_get_tree_item_available_asset_classes(self):
        """Test case for get_tree_item_available_asset_classes

        Gets available asset classes in the subtree rooted at treeItemId  # noqa: E501
        """
        pass

    def test_get_tree_item_children(self):
        """Test case for get_tree_item_children

        Gets the child groups under a TreeItem  # noqa: E501
        """
        pass

    def test_move_tree_item(self):
        """Test case for move_tree_item

        Moves a treeItem  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
