# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserProfileResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'acceleration_units': 'str',
        'date_format': 'str',
        'pressure_units': 'str',
        'temperature_units': 'str',
        'time_format': 'str',
        'time_zone': 'str',
        'velocity_units': 'str'
    }

    attribute_map = {
        'user_id': 'UserId',
        'acceleration_units': 'AccelerationUnits',
        'date_format': 'DateFormat',
        'pressure_units': 'PressureUnits',
        'temperature_units': 'TemperatureUnits',
        'time_format': 'TimeFormat',
        'time_zone': 'TimeZone',
        'velocity_units': 'VelocityUnits'
    }

    def __init__(self, user_id=None, acceleration_units=None, date_format=None, pressure_units=None, temperature_units=None, time_format=None, time_zone=None, velocity_units=None):  # noqa: E501
        """UserProfileResponse - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._acceleration_units = None
        self._date_format = None
        self._pressure_units = None
        self._temperature_units = None
        self._time_format = None
        self._time_zone = None
        self._velocity_units = None
        self.discriminator = None
        self.user_id = user_id
        self.acceleration_units = acceleration_units
        self.date_format = date_format
        self.pressure_units = pressure_units
        self.temperature_units = temperature_units
        self.time_format = time_format
        self.time_zone = time_zone
        self.velocity_units = velocity_units

    @property
    def user_id(self):
        """Gets the user_id of this UserProfileResponse.  # noqa: E501

        User ID  # noqa: E501

        :return: The user_id of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserProfileResponse.

        User ID  # noqa: E501

        :param user_id: The user_id of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def acceleration_units(self):
        """Gets the acceleration_units of this UserProfileResponse.  # noqa: E501

        Acceleration units  # noqa: E501

        :return: The acceleration_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._acceleration_units

    @acceleration_units.setter
    def acceleration_units(self, acceleration_units):
        """Sets the acceleration_units of this UserProfileResponse.

        Acceleration units  # noqa: E501

        :param acceleration_units: The acceleration_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if acceleration_units is None:
            raise ValueError("Invalid value for `acceleration_units`, must not be `None`")  # noqa: E501

        self._acceleration_units = acceleration_units

    @property
    def date_format(self):
        """Gets the date_format of this UserProfileResponse.  # noqa: E501

        Date format  # noqa: E501

        :return: The date_format of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._date_format

    @date_format.setter
    def date_format(self, date_format):
        """Sets the date_format of this UserProfileResponse.

        Date format  # noqa: E501

        :param date_format: The date_format of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if date_format is None:
            raise ValueError("Invalid value for `date_format`, must not be `None`")  # noqa: E501

        self._date_format = date_format

    @property
    def pressure_units(self):
        """Gets the pressure_units of this UserProfileResponse.  # noqa: E501

        Pressure units  # noqa: E501

        :return: The pressure_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._pressure_units

    @pressure_units.setter
    def pressure_units(self, pressure_units):
        """Sets the pressure_units of this UserProfileResponse.

        Pressure units  # noqa: E501

        :param pressure_units: The pressure_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if pressure_units is None:
            raise ValueError("Invalid value for `pressure_units`, must not be `None`")  # noqa: E501

        self._pressure_units = pressure_units

    @property
    def temperature_units(self):
        """Gets the temperature_units of this UserProfileResponse.  # noqa: E501

        Temperature units  # noqa: E501

        :return: The temperature_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._temperature_units

    @temperature_units.setter
    def temperature_units(self, temperature_units):
        """Sets the temperature_units of this UserProfileResponse.

        Temperature units  # noqa: E501

        :param temperature_units: The temperature_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if temperature_units is None:
            raise ValueError("Invalid value for `temperature_units`, must not be `None`")  # noqa: E501

        self._temperature_units = temperature_units

    @property
    def time_format(self):
        """Gets the time_format of this UserProfileResponse.  # noqa: E501

        Time format  # noqa: E501

        :return: The time_format of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._time_format

    @time_format.setter
    def time_format(self, time_format):
        """Sets the time_format of this UserProfileResponse.

        Time format  # noqa: E501

        :param time_format: The time_format of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if time_format is None:
            raise ValueError("Invalid value for `time_format`, must not be `None`")  # noqa: E501

        self._time_format = time_format

    @property
    def time_zone(self):
        """Gets the time_zone of this UserProfileResponse.  # noqa: E501

        Time zone  # noqa: E501

        :return: The time_zone of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this UserProfileResponse.

        Time zone  # noqa: E501

        :param time_zone: The time_zone of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if time_zone is None:
            raise ValueError("Invalid value for `time_zone`, must not be `None`")  # noqa: E501

        self._time_zone = time_zone

    @property
    def velocity_units(self):
        """Gets the velocity_units of this UserProfileResponse.  # noqa: E501

        Velocity units  # noqa: E501

        :return: The velocity_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._velocity_units

    @velocity_units.setter
    def velocity_units(self, velocity_units):
        """Sets the velocity_units of this UserProfileResponse.

        Velocity units  # noqa: E501

        :param velocity_units: The velocity_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if velocity_units is None:
            raise ValueError("Invalid value for `velocity_units`, must not be `None`")  # noqa: E501

        self._velocity_units = velocity_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserProfileResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserProfileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
