# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.hubs_api import HubsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestHubsApi(unittest.TestCase):
    """HubsApi unit test stubs"""

    def setUp(self):
        self.api = HubsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_hub_overview(self):
        """Test case for export_hub_overview

        Exports hub information  # noqa: E501
        """
        pass

    def test_get_hub(self):
        """Test case for get_hub

        Returns a single Hub with the supplied Id  # noqa: E501
        """
        pass

    def test_get_hubs(self):
        """Test case for get_hubs

        Gets all hubs a user has access to  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
