# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InstallNodeStatusChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status_id': 'int',
        'status': 'str',
        'status_date': 'datetime',
        'status_note': 'str',
        'install_user': 'str'
    }

    attribute_map = {
        'status_id': 'StatusId',
        'status': 'Status',
        'status_date': 'StatusDate',
        'status_note': 'StatusNote',
        'install_user': 'InstallUser'
    }

    def __init__(self, status_id=None, status=None, status_date=None, status_note=None, install_user=None):  # noqa: E501
        """InstallNodeStatusChild - a model defined in Swagger"""  # noqa: E501
        self._status_id = None
        self._status = None
        self._status_date = None
        self._status_note = None
        self._install_user = None
        self.discriminator = None
        self.status_id = status_id
        if status is not None:
            self.status = status
        if status_date is not None:
            self.status_date = status_date
        if status_note is not None:
            self.status_note = status_note
        if install_user is not None:
            self.install_user = install_user

    @property
    def status_id(self):
        """Gets the status_id of this InstallNodeStatusChild.  # noqa: E501

        The corresponding StatusId  # noqa: E501

        :return: The status_id of this InstallNodeStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this InstallNodeStatusChild.

        The corresponding StatusId  # noqa: E501

        :param status_id: The status_id of this InstallNodeStatusChild.  # noqa: E501
        :type: int
        """
        if status_id is None:
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def status(self):
        """Gets the status of this InstallNodeStatusChild.  # noqa: E501

        The textual description of the Status  # noqa: E501

        :return: The status of this InstallNodeStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InstallNodeStatusChild.

        The textual description of the Status  # noqa: E501

        :param status: The status of this InstallNodeStatusChild.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_date(self):
        """Gets the status_date of this InstallNodeStatusChild.  # noqa: E501

        The DateTime that the current status was set as part of an install activity  # noqa: E501

        :return: The status_date of this InstallNodeStatusChild.  # noqa: E501
        :rtype: datetime
        """
        return self._status_date

    @status_date.setter
    def status_date(self, status_date):
        """Sets the status_date of this InstallNodeStatusChild.

        The DateTime that the current status was set as part of an install activity  # noqa: E501

        :param status_date: The status_date of this InstallNodeStatusChild.  # noqa: E501
        :type: datetime
        """

        self._status_date = status_date

    @property
    def status_note(self):
        """Gets the status_note of this InstallNodeStatusChild.  # noqa: E501

        A brief note about the installation of the node, typically used when   something prevents a node from being installed to keep records  # noqa: E501

        :return: The status_note of this InstallNodeStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status_note

    @status_note.setter
    def status_note(self, status_note):
        """Sets the status_note of this InstallNodeStatusChild.

        A brief note about the installation of the node, typically used when   something prevents a node from being installed to keep records  # noqa: E501

        :param status_note: The status_note of this InstallNodeStatusChild.  # noqa: E501
        :type: str
        """

        self._status_note = status_note

    @property
    def install_user(self):
        """Gets the install_user of this InstallNodeStatusChild.  # noqa: E501

        The user that set the current install status  # noqa: E501

        :return: The install_user of this InstallNodeStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._install_user

    @install_user.setter
    def install_user(self, install_user):
        """Sets the install_user of this InstallNodeStatusChild.

        The user that set the current install status  # noqa: E501

        :param install_user: The install_user of this InstallNodeStatusChild.  # noqa: E501
        :type: str
        """

        self._install_user = install_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstallNodeStatusChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstallNodeStatusChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
