# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.assets_api import AssetsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestAssetsApi(unittest.TestCase):
    """AssetsApi unit test stubs"""

    def setUp(self):
        self.api = AssetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_asset(self):
        """Test case for create_asset

        Creates an asset  # noqa: E501
        """
        pass

    def test_create_asset_classification_category(self):
        """Test case for create_asset_classification_category

        Creates a category  # noqa: E501
        """
        pass

    def test_create_asset_classification_type(self):
        """Test case for create_asset_classification_type

        Creates an asset classification type  # noqa: E501
        """
        pass

    def test_delete_asset(self):
        """Test case for delete_asset

        Deletes an asset  # noqa: E501
        """
        pass

    def test_delete_asset_classification_category(self):
        """Test case for delete_asset_classification_category

        Deletes a category  # noqa: E501
        """
        pass

    def test_get_asset(self):
        """Test case for get_asset

        Gets an Asset  # noqa: E501
        """
        pass

    def test_get_asset_category_parameters(self):
        """Test case for get_asset_category_parameters

        Gets a list of Asset Classification parameters based on a given Category.  Includes any inherited parameters from any parent Categories.  # noqa: E501
        """
        pass

    def test_get_asset_classification_assignment(self):
        """Test case for get_asset_classification_assignment

        Gets the classification assignment for an asset  # noqa: E501
        """
        pass

    def test_get_asset_classification_categories(self):
        """Test case for get_asset_classification_categories

        Gets asset type categories.  # noqa: E501
        """
        pass

    def test_get_asset_classification_category(self):
        """Test case for get_asset_classification_category

        Gets a category by id  # noqa: E501
        """
        pass

    def test_get_asset_classification_type(self):
        """Test case for get_asset_classification_type

        Gets a type by id  # noqa: E501
        """
        pass

    def test_get_asset_classification_types(self):
        """Test case for get_asset_classification_types

        Gets a paged list of Asset Classification types  # noqa: E501
        """
        pass

    def test_get_asset_markers(self):
        """Test case for get_asset_markers

        Gets all markers on an asset  # noqa: E501
        """
        pass

    def test_get_asset_status(self):
        """Test case for get_asset_status

        Gets an asset's status  # noqa: E501
        """
        pass

    def test_get_asset_statuses(self):
        """Test case for get_asset_statuses

        Gets Asset Statuses  # noqa: E501
        """
        pass

    def test_get_asset_types(self):
        """Test case for get_asset_types

        This route is obsolete. Please use GET /api/v3.0/Assets/Classification/Types instead.  Gets Asset Types  # noqa: E501
        """
        pass

    def test_get_assets(self):
        """Test case for get_assets

        Gets Assets  # noqa: E501
        """
        pass

    def test_get_files_for_asset(self):
        """Test case for get_files_for_asset

        Gets an asset's files  # noqa: E501
        """
        pass

    def test_move_asset(self):
        """Test case for move_asset

        Moves an asset  # noqa: E501
        """
        pass

    def test_update_asset(self):
        """Test case for update_asset

        Updates an asset  # noqa: E501
        """
        pass

    def test_update_asset_classification_category(self):
        """Test case for update_asset_classification_category

        Updates a category  # noqa: E501
        """
        pass

    def test_update_asset_classification_parameters(self):
        """Test case for update_asset_classification_parameters

        Updates the parameters for a given category  # noqa: E501
        """
        pass

    def test_update_asset_classification_type(self):
        """Test case for update_asset_classification_type

        Updates an asset classification type  # noqa: E501
        """
        pass

    def test_update_classification_assignment(self):
        """Test case for update_classification_assignment

        Updates an assignment for classifications belonging to an asset.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
