# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.base_stations_api import BaseStationsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBaseStationsApi(unittest.TestCase):
    """BaseStationsApi unit test stubs"""

    def setUp(self):
        self.api = BaseStationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_base_station(self):
        """Test case for create_base_station

        Creates a Base Station  # noqa: E501
        """
        pass

    def test_edit_base_station(self):
        """Test case for edit_base_station

        """
        pass

    def test_export_base_stations(self):
        """Test case for export_base_stations

        Requests a Base Station export.  # noqa: E501
        """
        pass

    def test_get_base_station(self):
        """Test case for get_base_station

        Gets a Base Station by Id  # noqa: E501
        """
        pass

    def test_get_base_station_default_receiver_frequencies(self):
        """Test case for get_base_station_default_receiver_frequencies

        Returns a list of default Receiver Frequencies for a Base Station  # noqa: E501
        """
        pass

    def test_get_base_stations(self):
        """Test case for get_base_stations

        Gets a paged list of Base Stations  # noqa: E501
        """
        pass

    def test_reboot_base_station(self):
        """Test case for reboot_base_station

        Reboots a given Base station  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
