# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.monitoring_points_api import MonitoringPointsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestMonitoringPointsApi(unittest.TestCase):
    """MonitoringPointsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringPointsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_monitoring_point(self):
        """Test case for create_monitoring_point

        Creates a monitoringPoint  # noqa: E501
        """
        pass

    def test_delete_monitoring_point(self):
        """Test case for delete_monitoring_point

        Deletes a monitoringPoint  # noqa: E501
        """
        pass

    def test_get_monitoring_point(self):
        """Test case for get_monitoring_point

        Gets a Monitoring Point  # noqa: E501
        """
        pass

    def test_get_monitoring_point_assignments(self):
        """Test case for get_monitoring_point_assignments

        Gets all of the node assignment history for a monitoring point including the current assignment.  # noqa: E501
        """
        pass

    def test_get_monitoring_point_current_assignment(self):
        """Test case for get_monitoring_point_current_assignment

        Gets the currently assigned node to a monitoring point  # noqa: E501
        """
        pass

    def test_get_monitoring_point_overview(self):
        """Test case for get_monitoring_point_overview

        Gets an overview of monitoring point(s) which includes the node settings  # noqa: E501
        """
        pass

    def test_get_monitoring_points(self):
        """Test case for get_monitoring_points

        Gets Monitoring Points  # noqa: E501
        """
        pass

    def test_update_monitoring_point(self):
        """Test case for update_monitoring_point

        Updates a monitoringPoint  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
