# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.identity_providers_api import IdentityProvidersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestIdentityProvidersApi(unittest.TestCase):
    """IdentityProvidersApi unit test stubs"""

    def setUp(self):
        self.api = IdentityProvidersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_identity_provider(self):
        """Test case for create_identity_provider

        Creates a new identity provider  # noqa: E501
        """
        pass

    def test_get_identity_provider(self):
        """Test case for get_identity_provider

        Gets the identity provider with the provided ID  # noqa: E501
        """
        pass

    def test_get_identity_providers(self):
        """Test case for get_identity_providers

        Gets all identity providers  # noqa: E501
        """
        pass

    def test_update_identity_provider(self):
        """Test case for update_identity_provider

        Edits an identity provider  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
