# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.filters_api import FiltersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestFiltersApi(unittest.TestCase):
    """FiltersApi unit test stubs"""

    def setUp(self):
        self.api = FiltersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_indicator_filter(self):
        """Test case for create_indicator_filter

        Creates an indicator filter  # noqa: E501
        """
        pass

    def test_delete_indicator_filter(self):
        """Test case for delete_indicator_filter

        Deletes an indicator filter  # noqa: E501
        """
        pass

    def test_get_indicator_filter(self):
        """Test case for get_indicator_filter

        Gets a single indicator filter  # noqa: E501
        """
        pass

    def test_get_indicator_filters(self):
        """Test case for get_indicator_filters

        Gets many indicator filters  # noqa: E501
        """
        pass

    def test_update_indicator_filter(self):
        """Test case for update_indicator_filter

        Updates an indicator filter  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
