# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.hardware_status_api import HardwareStatusApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestHardwareStatusApi(unittest.TestCase):
    """HardwareStatusApi unit test stubs"""

    def setUp(self):
        self.api = HardwareStatusApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_collectors_status(self):
        """Test case for get_collectors_status

        Gets the online status for the desired base stations.  # noqa: E501
        """
        pass

    def test_get_hubs_status(self):
        """Test case for get_hubs_status

        Gets all status for hubs.  # noqa: E501
        """
        pass

    def test_get_nodes_status(self):
        """Test case for get_nodes_status

        Gets all status for nodes.  # noqa: E501
        """
        pass

    def test_get_repeaters_status(self):
        """Test case for get_repeaters_status

        Gets the online status for repeaters, grouped by location.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
